(this["webpackJsonp@dagit/app"]=this["webpackJsonp@dagit/app"]||[]).push([[10],{1117:function(e,t,n){"use strict";n.r(t);var c=n(27),i=n(17),o=n(35),a=n(1),r=n(652),s=n(78),u=n(21),f=n(121),l=n(651),d=n(215),j=n(82),b=n(46),g=n(1110),p=n(98),h=n.n(p),O=n(113),v=n(224),x=n(0),k=function(e){var t=Math.abs(e);return"".concat(e<0?"+":"-").concat(Math.floor(t/60),":").concat(t%60<10?"0":"").concat(t%60)},m=h.a.tz.names().map((function(e){var t,n=(null===(t=h.a.tz.zone(e))||void 0===t?void 0:t.utcOffset(Date.now()))||0;return{offsetLabel:"".concat(k(n)),offset:n,key:e}})).sort((function(e,t){return e.offset-t.offset})),y=["UTC","US/Pacific","US/Mountain","US/Central","US/Eastern"],w=[{key:"Automatic",offsetLabel:function(){var e;return"".concat(Object(v.c)()," ").concat(k((null===(e=h.a.tz.zone(Object(v.b)()))||void 0===e?void 0:e.utcOffset(Date.now()))||0))}(),offset:0},{key:"divider-1",offsetLabel:"",offset:0}].concat(Object(c.a)(m.filter((function(e){return y.includes(e.key)}))),[{key:"divider-2",offsetLabel:"",offset:0}],Object(c.a)(m.filter((function(e){return!y.includes(e.key)})))),C=function(e){var t=e.trigger,n=a.useContext(O.a),c=Object(i.a)(n,2),r=c[0],s=c[1];return Object(x.jsx)(g.a,{popoverProps:{position:"bottom-right"},activeItem:w.find((function(e){return e.key===r})),inputProps:{style:{width:"300px"}},items:w,itemPredicate:function(e,t){return t.key.toLowerCase().includes(e.toLowerCase())},itemRenderer:function(e,t){return e.key.startsWith("divider")?Object(x.jsx)(o.n.Divider,{},e.key):Object(x.jsx)(o.n.Item,{active:t.modifiers.active,onClick:t.handleClick,label:e.offsetLabel,text:e.key},e.key)},noResults:Object(x.jsx)(o.n.Item,{disabled:!0,text:"No results."}),onItemSelect:function(e){return s(e.key)},children:t(r)})};t.default=function(){Object(r.a)("User settings");var e=a.useState((function(){return Object(b.c)()})),t=Object(i.a)(e,2),n=t[0],g=t[1];a.useEffect((function(){Object(b.d)(n)}));var p=function(e){g(n.includes(e)?n.filter((function(t){return t!==e})):[].concat(Object(c.a)(n),[e])),window.location.reload()},h=a.useCallback((function(e){return Object(x.jsx)(s.a,{children:"Automatic"===e?Object(v.a)():e})}),[]);return Object(x.jsx)(l.a,{style:{height:"100vh",overflowY:"auto"},children:Object(x.jsxs)(u.a,{direction:"column",spacing:24,children:[Object(x.jsx)(d.a,{title:Object(x.jsx)(j.d,{children:"User settings"})}),Object(x.jsxs)(u.a,{direction:"column",spacing:16,children:[Object(x.jsx)(j.f,{children:"Preferences"}),Object(x.jsx)(f.a,{rows:[{key:"Timezone",value:Object(x.jsx)(C,{trigger:h})}]})]}),Object(x.jsxs)(u.a,{direction:"column",spacing:16,children:[Object(x.jsx)(j.f,{children:"Experimental features"}),Object(x.jsx)(f.a,{rows:[{key:"Debug console logging",value:Object(x.jsx)(o.A,{checked:n.includes(b.a.flagDebugConsoleLogging),onChange:function(){return p(b.a.flagDebugConsoleLogging)}})},{key:"Experimental Core APIs (Job & Graph)",value:Object(x.jsx)(o.A,{checked:n.includes(b.a.flagPipelineModeTuples),onChange:function(){return p(b.a.flagPipelineModeTuples)}})},{key:"Experimental Asset APIs",value:Object(x.jsx)(o.A,{checked:n.includes(b.a.flagAssetGraph),onChange:function(){return p(b.a.flagAssetGraph)}})}]})]})]})})}},651:function(e,t,n){"use strict";n.d(t,"a",(function(){return c}));var c=n(6).c.div.withConfig({displayName:"Page",componentId:"sc-169p5e-0"})(["overflow-y:auto;padding:20px;width:100%;"])},652:function(e,t,n){"use strict";n.d(t,"a",(function(){return i}));var c=n(1),i=function(e){c.useEffect((function(){var t=document.title;return document.title=e,function(){document.title=t}}),[e])}}}]);
//# sourceMappingURL=10.9a0ea7cb.chunk.js.map